gnugo-devel
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[gnugo-devel] New patch for name corrections


From: Marcin Garski
Subject: [gnugo-devel] New patch for name corrections
Date: Tue, 31 Jan 2006 00:30:01 +0100
User-agent: Mozilla Thunderbird 1.5 (Linux)

Hello,

This is probably second and the last patch that fix the rest names in GNU Go.

--
Marcin Garski
diff -ur gnugo-3.7.8-orig/configure.in gnugo-3.7.8/configure.in
--- gnugo-3.7.8-orig/configure.in       2006-01-30 19:59:36.000000000 +0100
+++ gnugo-3.7.8/configure.in    2006-01-31 00:11:21.000000000 +0100
@@ -34,8 +34,8 @@
 dnl "yes" if enabled, or undefined if not specified
 
 AC_ARG_WITH(readline,
- [  --with-readline     try to use GNU readline for command reading
-  --without-readline  do not use GNU readline (default)])
+ [  --with-readline     try to use GNU Readline for command reading
+  --without-readline  do not use GNU Readline (default)])
 
 AC_ARG_WITH(curses,
  [  --with-curses       try to use curses for colored debugging output 
(default)
@@ -184,7 +184,7 @@
 dnl usleep not available in Unicos and mingw32
 AC_CHECK_FUNCS(vsnprintf gettimeofday usleep times)
 
-dnl if snprintf not available try to use g_snprintf from glib
+dnl if snprintf not available try to use g_snprintf from GLib
 if test $ac_cv_func_vsnprintf = no; then
     AC_CHECK_PROG(glibconfig,glib-config,yes,no)
     if test $ac_cv_prog_glibconfig = yes;then
@@ -195,12 +195,12 @@
        AC_CHECK_FUNCS(g_vsnprintf)
        AC_CHECK_HEADERS(glib.h)
        if test $ac_cv_func_g_vsnprintf = no; then
-          AC_MSG_WARN([glib installation problem.
-          Continuing without glib ])
+          AC_MSG_WARN([GLib installation problem.
+          Continuing without GLib ])
         fi
     else
-          AC_MSG_WARN([Neither vsnprintf nor glib found. GNU Go is
-          compiled but it is safer to get glib at
+          AC_MSG_WARN([Neither vsnprintf nor GLib found. GNU Go is
+          compiled but it is safer to get GLib at
           http://www.gtk.org/])
     fi
 fi
diff -ur gnugo-3.7.8-orig/doc/install.texi gnugo-3.7.8/doc/install.texi
--- gnugo-3.7.8-orig/doc/install.texi   2006-01-27 16:49:22.000000000 +0100
+++ gnugo-3.7.8/doc/install.texi        2006-01-31 00:12:13.000000000 +0100
@@ -273,7 +273,7 @@
 @end enumerate
 
 The rest of this section gives more details on the various ways
-to compile GNU Go for for Microsoft platforms.
+to compile GNU Go for Microsoft platforms.
 
 @menu Using free Unix-environments and GCC
 * DJGPP::      Windows 95/98, MS-DOS and Windows 3.x using DJGPP
@@ -311,7 +311,7 @@
        make
 @end example
 
-Optionally you can download glib for DJGPP to get a working version
+Optionally you can download GLib for DJGPP to get a working version
 of snprintf.
 
 @node Cygwin
diff -ur gnugo-3.7.8-orig/interface/gtp_examples/gnugo.el 
gnugo-3.7.8/interface/gtp_examples/gnugo.el
--- gnugo-3.7.8-orig/interface/gtp_examples/gnugo.el    2005-06-12 
11:34:14.000000000 +0200
+++ gnugo-3.7.8/interface/gtp_examples/gnugo.el 2006-01-30 23:41:40.000000000 
+0100
@@ -43,10 +43,10 @@
 ;;; Variables
 
 (defvar gnugo-board-mode-map nil
-  "Keymap for GNUGO Board mode.")
+  "Keymap for GNU Go Board mode.")
 
 (defvar gnugo-option-history nil
-  "History of additional GNUGO command-line options.")
+  "History of additional GNU Go command-line options.")
 
 (defvar gnugo-animation-string
   (let ((jam "*#") (blink " #") (spin "-\\|/") (yada "*-*!"))
@@ -488,7 +488,7 @@
                 (put cmd 'gnugo-post-function nil)))))))))
 
 ;;;---------------------------------------------------------------------------
-;;; Major mode for interacting with a GNUGO subprocess
+;;; Major mode for interacting with a GNU Go subprocess
 
 (defun gnugo-board-mode ()
   "In this mode, keys do not self insert.
@@ -521,14 +521,14 @@
   !             Estimate score (at any time).
 
   : or ;        Extended command.  Type in a string to be passed (quite
-                indirectly) to the GNUGO subprocess.  Output and emacs
+                indirectly) to the GNU Go subprocess.  Output and emacs
                 behavior depend on which command is given.  Try `help'
                 to get a list of all commands.  Note that some commands
                 may confuse gnugo.el."
   (kill-all-local-variables)
   (use-local-map gnugo-board-mode-map)
   (setq major-mode 'gnugo-board-mode)
-  (setq mode-name "GNUGO Board"))
+  (setq mode-name "GNU Go Board"))
 
 ;;;---------------------------------------------------------------------------
 ;;; Entry point
diff -ur gnugo-3.7.8-orig/README gnugo-3.7.8/README
--- gnugo-3.7.8-orig/README     2006-01-27 16:49:21.000000000 +0100
+++ gnugo-3.7.8/README  2006-01-30 23:42:31.000000000 +0100
@@ -104,7 +104,7 @@
    * `Return' or `Space'
           Select point as the next move.  An error is signalled for
           invalid locations.  Illegal locations, on the other hand,
-          show up in the GNUGO Console buffer.
+          show up in the GNU Go Console buffer.
 
    * `q' or `Q'
           Quit. Both Board and Console buffers are deleted.
@@ -123,7 +123,7 @@
 
    * `:'
           Extended command.  Type in a string to be passed directly to
-          the inferior GNUGO process."
+          the inferior GNU Go process."
 
 
 
diff -ur gnugo-3.7.8-orig/TODO gnugo-3.7.8/TODO
--- gnugo-3.7.8-orig/TODO       2005-10-23 22:43:37.000000000 +0200
+++ gnugo-3.7.8/TODO    2006-01-31 00:14:34.000000000 +0100
@@ -154,7 +154,7 @@
 are presented here for inspiration.
 
  * A good GUI.
-   A start is being made with GoThic, a goban widget based on the QT
+   A start is being made with GoThic, a goban widget based on the Qt
    toolkit.  This is linked from the GNU Go development web page on
    gnu.org. Other starts have been made based on GTK+, but so far
    nothing more than a start has been attempted.
diff -ur gnugo-3.7.8-orig/WINDOWS gnugo-3.7.8/WINDOWS
--- gnugo-3.7.8-orig/WINDOWS    2005-10-23 22:47:38.000000000 +0200
+++ gnugo-3.7.8/WINDOWS 2006-01-31 00:11:40.000000000 +0100
@@ -67,7 +67,7 @@
        ./configure
        make
 
-Optionally you can download glib for DJGPP to get a working version
+Optionally you can download GLib for DJGPP to get a working version
 of snprintf.
 
 B) Windows NT, Windows 95/98 using Cygwin
@@ -92,8 +92,8 @@
 
    <http://cygwin.com/>
 
-   Optionally you can use glib to get a working version of snprintf.
-Glib builds out of the box on cygwin.
+   Optionally you can use GLib to get a working version of snprintf.
+GLib builds out of the box on cygwin.
 
 C) Windows NT, Windows 95/98 using MINGW32
 

reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff -ur gnugo-3.7.8-orig/doc/introduction.texi 
gnugo-3.7.8/doc/introduction.texi
--- gnugo-3.7.8-orig/doc/introduction.texi      2006-01-27 16:49:22.000000000 
+0100
+++ gnugo-3.7.8/doc/introduction.texi   2006-01-31 00:14:47.000000000 +0100
@@ -299,7 +299,7 @@
 @itemize
 @item A good GUI.
 @quotation
-A start is being made with GoThic, a goban widget based on the QT
+A start is being made with GoThic, a goban widget based on the Qt
 toolkit.  This is linked from the GNU Go development web page on
 gnu.org. Other starts have been made based on GTK+, but so far
 nothing more than a start has been attempted.
diff -ur gnugo-3.7.8-orig/interface/gnugo.el gnugo-3.7.8/interface/gnugo.el
--- gnugo-3.7.8-orig/interface/gnugo.el 2006-01-27 16:49:23.000000000 +0100
+++ gnugo-3.7.8/interface/gnugo.el      2006-01-30 23:38:34.000000000 +0100
@@ -101,10 +101,10 @@
 ;; - talk GTP over the network
 ;; - "assist minor mode" (see gnugo-extra.el for work in progress)
 ;; - using assist minor mode, gnugo-v-gnugo (ibid)
 ;; - extract GNUGO Board mode and sgf stuff into sgf.el; make gnugo.el use it
 ;; - make gnugo (the external program) support query (read-only) thread
 ;;   so as to be able to lift "still waiting" restriction
 ;; - alternatively, extend GNUGO Board mode to manage another subprocess
 ;;   dedicated to analysis (no genmove)
 ;; - command `C' to add a comment to the sgf tree
 ;; - command `C-u =' to label a position
@@ -204,16 +204,16 @@
 http://www.gnu.org/software/gnugo";)
 
 (defvar gnugo-board-mode-map nil
-  "Keymap for GNUGO Board mode.")
+  "Keymap for GNU Go Board mode.")
 
 (defvar gnugo-board-mode-hook nil
-  "*Hook run when entering GNUGO Board mode.")
+  "*Hook run when entering GNU Go Board mode.")
 
 (defvar gnugo-post-move-hook nil
   "*Normal hook run after a move and before the board is refreshed.
 Hook functions can prevent the call to `gnugo-refresh' by evaluating:
   (setq inhibit-gnugo-refresh t)
-Initially, when `run-hooks' is called, the current buffer is the GNUGO
+Initially, when `run-hooks' is called, the current buffer is the GNU Go
 Board buffer of the game.  Hook functions that switch buffers must take
 care not to call (directly or indirectly through some other function)
 `gnugo-put' or `gnugo-get' after the switch.")
@@ -239,7 +239,7 @@
 the viewer) is exhausted.")
 
 (defvar gnugo-mode-line "~b ~w :~m ~n :~u"
-  "*A `mode-line-format'-compliant value for GNUGO Board mode.
+  "*A `mode-line-format'-compliant value for GNU Go Board mode.
 If a single string, the following special escape sequences are
 replaced with their associated information:
   ~b,~w  black,white captures (a number)
@@ -310,7 +310,7 @@
 \(This docstring is shared by `gnugo-put' and `gnugo-get'.\)
 
 There are many properties, each named by a keyword, that record and control
-how gnugo.el manages each game.  Each GNUGO Board buffer has its own set
+how gnugo.el manages each game.  Each GNU Go Board buffer has its own set
 of properties, stored in the hash table `gnugo-state'.  Here we document
 some of the more stable properties.  You may wish to use them as part of
 a `gnugo-post-move-hook' function, for example.  Be careful to preserve
@@ -370,11 +370,11 @@
   (put 'gnugo-get 'function-documentation docs))
 
 (defun gnugo-board-buffer-p (&optional buffer)
-  "Return non-nil if BUFFER is a GNUGO Board buffer."
+  "Return non-nil if BUFFER is a GNU Go Board buffer."
   (with-current-buffer (or buffer (current-buffer)) gnugo-state))
 
 (defun gnugo-board-user-play-ok-p (&optional buffer)
-  "Return non-nil if BUFFER is a GNUGO Board buffer ready for a user move."
+  "Return non-nil if BUFFER is a GNU Go Board buffer ready for a user move."
   (with-current-buffer (or buffer (current-buffer))
     (and gnugo-state (not (gnugo-get :waitingp)))))
 
@@ -885,7 +885,7 @@
     (create-image new 'xpm t :ascent 'center)))
 
 (defun gnugo-refresh (&optional nocache)
-  "Update GNUGO Board buffer display.
+  "Update GNU Go Board buffer display.
 While a game is in progress, parenthesize the last-played stone (no parens
 for pass).  If the buffer is currently displayed in the selected window,
 recenter the board (presuming there is extra space in the window).  Update
@@ -1083,7 +1083,7 @@
       (error "Not a proper position point")))
 
 (defun gnugo-move ()
-  "Make a move on the GNUGO Board buffer.
+  "Make a move on the GNU Go Board buffer.
 The position is computed from current point.
 Signal error if done out-of-turn or if game-over.
 To start a game try M-x gnugo."
@@ -1116,7 +1116,7 @@
     (gnugo-move)))
 
 (defun gnugo-pass ()
-  "Make a pass on the GNUGO Board buffer.
+  "Make a pass on the GNU Go Board buffer.
 Signal error if done out-of-turn or if game-over.
 To start a game try M-x gnugo."
   (interactive)
@@ -1203,7 +1203,7 @@
   (message "Computing %s ... done." command))
 
 (defun gnugo-worm-stones ()
-  "In the GNUGO Board buffer, animate \"worm\" at current position.
+  "In the GNU Go Board buffer, animate \"worm\" at current position.
 Signal error if done out-of-turn or if game-over.
 See variable `gnugo-animation-string' for customization."
   (interactive)
@@ -1218,7 +1218,7 @@
   (gnugo-display-group-data "worm_data" "*gnugo worm data*"))
 
 (defun gnugo-dragon-stones ()
-  "In the GNUGO Board buffer, animate \"dragon\" at current position.
+  "In the GNU Go Board buffer, animate \"dragon\" at current position.
 Signal error if done out-of-turn or if game-over.
 See variable `gnugo-animation-string' for customization."
   (interactive)
@@ -1233,7 +1233,7 @@
   (gnugo-display-group-data "dragon_data" "*gnugo dragon data*"))
 
 (defun gnugo-toggle-dead-group ()
-  "In a GNUGO Board buffer, during game-over, toggle a group as dead.
+  "In a GNU Go Board buffer, during game-over, toggle a group as dead.
 The group is selected from current position (point).  Signal error if
 not in game-over or if there is no group at that position.
 
@@ -1472,7 +1472,7 @@
   (gnugo-redo))
 
 (defun gnugo-magic-undo (spec &optional noalt)
-  "Undo moves on the GNUGO Board, based on SPEC, a string or number.
+  "Undo moves on the GNU Go Board, based on SPEC, a string or number.
 If SPEC is a string in the form of a board position (e.g., \"T19\"),
 check that the position is occupied by a stone of the user's color,
 and if so, remove moves from the history until that position is clear.
@@ -1751,7 +1751,7 @@
       (setcar n1p (append `((:RE . ,result)
                             (:C . ,blurb))
                           (car n1p))))
-    (switch-to-buffer (format "%s*GNUGO Final Score*"
+    (switch-to-buffer (format "%s*GNU Go Final Score*"
                               (gnugo-get :diamond)))
     (when (= 0 (buffer-size))
       (insert blurb))))
@@ -1821,7 +1821,7 @@
               (run-hooks 'hook))))))))
 
 ;;;---------------------------------------------------------------------------
 ;;; Major mode for interacting with a GNUGO subprocess
 
 (put 'gnugo-board-mode 'mode-class 'special)
 (defun gnugo-board-mode ()
@@ -1895,7 +1895,7 @@
   or C-x C-s
 
   l             Run `gnugo-read-sgf-file'."
-  (switch-to-buffer (generate-new-buffer "(Uninitialized GNUGO Board)"))
+  (switch-to-buffer (generate-new-buffer "(Uninitialized GNU Go Board)"))
   (buffer-disable-undo)                 ; todo: undo undo undoing
   (kill-all-local-variables)
   (setq truncate-lines t)
@@ -101,10 +101,10 @@
 ;; - "assist minor mode" (see gnugo-extra.el for work in progress)
 ;; - using assist minor mode, gnugo-v-gnugo (ibid)
-;; - extract GNUGO Board mode and sgf stuff into sgf.el; make gnugo.el use it
+;; - extract GNU Go Board mode and sgf stuff into sgf.el; make gnugo.el use it
 ;; - make gnugo (the external program) support query (read-only) thread
 ;;   so as to be able to lift "still waiting" restriction
@@ -101,10 +101,10 @@
 ;; - make gnugo (the external program) support query (read-only) thread
 ;;   so as to be able to lift "still waiting" restriction
-;; - alternatively, extend GNUGO Board mode to manage another subprocess
+;; - alternatively, extend GNU Go Board mode to manage another subprocess
 ;;   dedicated to analysis (no genmove)
 ;; - command `C' to add a comment to the sgf tree
@@ -1821,7 +1821,7 @@
 
 ;;;---------------------------------------------------------------------------
-;;; Major mode for interacting with a GNUGO subprocess
+;;; Major mode for interacting with a GNU Go subprocess
 
 (put 'gnugo-board-mode 'mode-class 'special)